from __future__ import print_function

from readingData.readingData import ReadCSV
from core.core import CreateSVM
import numpy as np
import pandas as pd
def main():
    print("-------------------------------------")
    readCSV = ReadCSV()
    df = readCSV.df
    print("Dataset read")
    print("-------------------------------------")
    #readCSV.making_print()
    createSVM = CreateSVM()
    print("Dataset splitted")
    Xtrain, Xtest,Ytrain, Ytest = createSVM.split(df['Fare'],df['Survived'])
    print("-------------------------------------")
    svcFitted = createSVM.fit(Xtrain[:,np.newaxis],Ytrain)
    print("SVM trained")
    svcScore = createSVM.get_score(svcFitted, Xtest[:,np.newaxis], Ytest)
    print('Score '+ str(svcScore))
    dfPred = pd.DataFrame(createSVM.predict(svcFitted), columns=['Fare', 'Survived'])
    print("-------------------------------------")
    print("Predictions")
    print(dfPred)
main()



import numpy as np
from sklearn.svm import SVC
from sklearn.model_selection import train_test_split
import pandas as pd
class CreateSVM():

    def split(self,dfTrain, dftargetLabel):
        return train_test_split(dfTrain, dftargetLabel, test_size=0.3, random_state=2)

    def fit(self,X,Y):
        svc = SVC()
        return svc.fit(X,Y)

    def get_score(self,svcFitted, X,Y):
        return svcFitted.score(X,Y)


    def predict(self,svcFitted):
        X =100*np.random.sample((10,1))
        y = svcFitted.predict(X).reshape(10,1)
        return  np.concatenate((X,y), axis=1)








from __future__ import print_function
import pandas as pd
from os import path
class ReadCSV(object):
    def __init__(self):
        here = path.dirname(path.dirname(path.abspath(__file__)))
        pathFile = path.join(here,"data")
        pathFile = path.join(pathFile, "train.csv")
        print(pathFile)
        self.df = pd.read_csv(pathFile)

    def making_print(self):
        print (self.df)